.. Cagou (Salut à Toi) documentation master file, created by
   sphinx-quickstart on Tue Jul 23 20:07:36 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Cagou (Salut à Toi) documentation
=================================

Welcome to Cagou's documentation. You'll find here both end-user end developer documentations.

Cagou is the desktop/mobile frontend of Salut à Toi (or SàT), a Libre communication ecosystem based on XMPP standard.

You can follow this documentation to learn more on it, or join our official XMPP room at `sat@chat.jabberfr.org <xmpp:sat@chat.jabberfr.org?join>`_ (also available via a `web link <https://chat.jabberfr.org/converse.js/sat@chat.jabberfr.org>`_)


.. toctree::
   :maxdepth: 3
   :caption: Contents:

   installation.rst



Indices and tables
==================

* :ref:`genindex`

..
    * :ref:`modindex`

* :ref:`search`
